==> sl-cia-4.0.374.tgz: package/lib/cia.js <==
var BuildDiffProcess = require("./build-diff-process.js").BuildDiffProcess,
    loggerFactory = require("./sl-logger.js").logger,
    expandCommaSeparatedValues = require('./utils').expandCommaSeparatedValues,
    SlJsInfra = require('sl-js-infra').SlJsInfra,
    DefaultValuesResolver = require('./default-values-resolver'),
    sourceControlProviders = require('./source-control-providers.js'),
    agentInstanceData = require('./current-agent-instance'),
    utils = require('./utils.js');

function CIA() {
}

CIA.prototype.run = function run(buildArguments, callback) {
    console.log('SeaLights Build agent ' + require("../package.json").version);
    var context = this;
    this.setDefaultsArguments(buildArguments);
    var logger = loggerFactory(buildArguments);
    printConfiguration(buildArguments, logger);
    try {
        var packageJsonFile = getPackageJsonFile(buildArguments.workspacepath, logger)
        notifyAgentStarted(buildArguments, logger, packageJsonFile).then(function () {
            var parsedDependencies = context._tryParseDependenciesForIntegrationBuild(buildArguments, logger);
            var buildMappingProxy = new SlJsInfra.BackendProxy(agentInstanceData, buildArguments, logger);
            context.runBuildDiffProcess(buildMappingProxy, parsedDependencies, buildArguments, logger, callback);
        }).catch(function (e) {
            callback(e)
        })
    } catch (e) {
        callback(e);
    }
}

CIA.prototype.runBuildDiffProcess = function(buildMappingProxy, parsedDependencies, buildArguments, logger, callback) {
    var buildDiffProcess = new BuildDiffProcess(buildArguments, buildMappingProxy, sourceControlProviders, parsedDependencies, logger);
    buildDiffProcess.run(buildArguments).then(function () {
        shutdownAgent(logger, buildArguments, null, callback);
    }).catch(function (err) {
        logger.error(err);
        shutdownAgent(logger, buildArguments, err, callback);
    });
}

CIA.prototype.setDefaultsArguments = function(buildArguments) {
    var defaults = this._createDefaults();
    for (var i in defaults) {
        if (!buildArguments[i]) {
            buildArguments[i] = defaults[i];
        }
    }
    buildArguments.includedFiles = expandCommaSeparatedValues(buildArguments.includedFiles);
    buildArguments.excludedFiles = expandCommaSeparatedValues(buildArguments.excludedFiles);
}

CIA.prototype._tryParseDependenciesForIntegrationBuild = function (buildArguments, logger) {
    try {
        if (buildArguments.dependency) {
            return SlJsInfra.DependencyUtils.parseDependencies(buildArguments.dependency, logger);
        } else if (buildArguments.dependenciesFile) {
            return SlJsInfra.DependencyUtils.parseDependenciesFile(utils.readJsonSync(buildArguments.dependenciesFile), logger);
        } else return [];
    } catch(err) {
        logger.error("Error parsing dependencies", err);
    }
}

CIA.prototype._createDefaults = function(){
    var defaultValuesResolver = new DefaultValuesResolver();
    return {
        "includedFiles": defaultValuesResolver.getIncludedFiles(),
        "excludedFiles": defaultValuesResolver.getExcludedFiles(),
        "prefixesOfExcludedFiles": process.env["SL_prefixesOfExcludedFiles"] ? process.env["SL_prefixesOfExcludedFiles"] : "~, :, webpack, node_modules",
        "delayShutdownInSeconds":30
    };
}

function printConfiguration(cfg, logger) {
    logger.info("***************************************************************");
    logger.info("Current Configuration: ");
    logger.info("***************************************************************");

    for(p in cfg)
    {
        if (typeof cfg[p] != "function"){
            logger.info(p + ":", cfg[p]);
        }
    }

    logger.info("***************************************************************");

}

function notifyAgentStarted(buildArguments, logger, packageJsonFile){
    var loader = new SlJsInfra.ConfigLoader();
    var agentConfig = loader.loadAgentConfiguration(buildArguments);
    return new SlJsInfra.CockpitNotifier.notifyStart(agentConfig, agentInstanceData, true, logger, packageJsonFile);
}

function getPackageJsonFile(path, logger) {
    if (!path) return null;
    try {
        var packageFilePath = SlJsInfra.Utils.FileUtils.findFileUp("package.json", path);
        return require(packageFilePath);
    } catch (e) {
        logger.info("Could not find package.json file in path '%s'");
        return null
    }
}

//TODO: [SLDEV-4709] Verify if we can remove this completely. Should check how SlNodeJS invokes it.
function sendLastLogs(cfg, logger, callback) {
    if (cfg.sendLogs) {
        logger.remoteStream.checkBuffer(true, function (err) {
            callback();
        })
    } else {
        callback();
    }
}

function shutdownAgent(logger, cfg, err, callback) {
    sendLastLogs(cfg, logger, function () {
        SlJsInfra.CockpitNotifier.notifyShutdown().then(function () {
            callback(err);
        })
    });}

module.exports.CIA = CIA;

==> sl-cia-5.0.485.tgz: package/lib/cia.js <==
var BuildDiffProcess = require("./build-diff-process.js").BuildDiffProcess,
    loggerFactory = require("./sl-logger.js").logger,
    expandCommaSeparatedValues = require('./utils').expandCommaSeparatedValues,
    SlJsInfra = require('sl-js-infra').SlJsInfra,
    DefaultValuesResolver = require('./default-values-resolver'),
    sourceControlProviders = require('./source-control-providers.js'),
    agentInstanceData = require('./current-agent-instance'),
    utils = require('./utils.js');

function CIA() {
}

CIA.prototype.run = function run(buildArguments, callback) {
    console.log('SeaLights Build agent ' + require("../package.json").version);
    var context = this;
    this.setDefaultsArguments(buildArguments);
    var logger = loggerFactory(buildArguments);
    printConfiguration(buildArguments, logger);
    try {
        var packageJsonFile = getPackageJsonFile(buildArguments.workspacepath, logger)
        notifyAgentStarted(buildArguments, logger, packageJsonFile).then(function () {
            var parsedDependencies = context._tryParseDependenciesForIntegrationBuild(buildArguments, logger);
            var buildMappingProxy = new SlJsInfra.BackendProxy(agentInstanceData, buildArguments, logger);
            context.runBuildDiffProcess(buildMappingProxy, parsedDependencies, buildArguments, logger, callback);
        }).catch(function (e) {
            callback(e)
        })
    } catch (e) {
        callback(e);
    }
}

CIA.prototype.runBuildDiffProcess = function(buildMappingProxy, parsedDependencies, buildArguments, logger, callback) {
    var buildDiffProcess = new BuildDiffProcess(buildArguments, buildMappingProxy, sourceControlProviders, parsedDependencies, logger);
    buildDiffProcess.run(buildArguments).then(function () {
        shutdownAgent(logger, buildArguments, null, callback);
    }).catch(function (err) {
        logger.error(err);
        shutdownAgent(logger, buildArguments, err, callback);
    });
}

CIA.prototype.setDefaultsArguments = function(buildArguments) {
    var defaults = this._createDefaults();
    for (var i in defaults) {
        if (!buildArguments[i]) {
            buildArguments[i] = defaults[i];
        }
    }
    buildArguments.includedFiles = expandCommaSeparatedValues(buildArguments.includedFiles);
    buildArguments.excludedFiles = expandCommaSeparatedValues(buildArguments.excludedFiles);
}

CIA.prototype._tryParseDependenciesForIntegrationBuild = function (buildArguments, logger) {
    try {
        if (buildArguments.dependency) {
            return SlJsInfra.DependencyUtils.parseDependencies(buildArguments.dependency, logger);
        } else if (buildArguments.dependenciesFile) {
            return SlJsInfra.DependencyUtils.parseDependenciesFile(utils.readJsonSync(buildArguments.dependenciesFile), logger);
        } else return [];
    } catch(err) {
        logger.error("Error parsing dependencies", err);
    }
}

CIA.prototype._createDefaults = function(){
    var defaultValuesResolver = new DefaultValuesResolver();
    return {
        "includedFiles": defaultValuesResolver.getIncludedFiles(),
        "excludedFiles": defaultValuesResolver.getExcludedFiles(),
        "prefixesOfExcludedFiles": process.env["SL_prefixesOfExcludedFiles"] ? process.env["SL_prefixesOfExcludedFiles"] : "~, :, webpack, node_modules",
        "delayShutdownInSeconds":30
    };
}

function printConfiguration(cfg, logger) {
    logger.info("***************************************************************");
    logger.info("Current Configuration: ");
    logger.info("***************************************************************");

    for(p in cfg)
    {
        if (typeof cfg[p] != "function"){
            logger.info(p + ":", cfg[p]);
        }
    }

    logger.info("***************************************************************");

}

function notifyAgentStarted(buildArguments, logger, packageJsonFile){
    var loader = new SlJsInfra.ConfigLoader();
    var agentConfig = loader.loadAgentConfiguration(buildArguments);
    return SlJsInfra.CockpitNotifier.notifyStart(agentConfig, agentInstanceData, true, logger, packageJsonFile);
}

function getPackageJsonFile(path, logger) {
    if (!path) return null;
    try {
        var packageFilePath = SlJsInfra.Utils.FileUtils.findFileUp("package.json", path);
        return require(packageFilePath);
    } catch (e) {
        logger.info("Could not find package.json file in path '%s'");
        return null
    }
}

//TODO: [SLDEV-4709] Verify if we can remove this completely. Should check how SlNodeJS invokes it.
function sendLastLogs(cfg, logger, callback) {
    if (cfg.sendLogs) {
        logger.remoteStream.checkBuffer(true, function (err) {
            callback();
        })
    } else {
        callback();
    }
}

function shutdownAgent(logger, cfg, err, callback) {
    sendLastLogs(cfg, logger, function () {
        SlJsInfra.CockpitNotifier.notifyShutdown().then(function () {
            callback(err);
        })
    });}

module.exports.CIA = CIA;
